@@ -7,6 +7,7 @@ from openpyxl.worksheet.worksheet import Worksheet
 from openpyxl_image_loader import SheetImageLoader
 from openpyxl.drawing.image import Image
 
+from domain.shared.text_line import TextLine
 from xlsx_lib.domain.distribution.data_block import DataBlock
 from xlsx_lib.domain.distribution.distribution_image import DistributionImage
 from xlsx_lib.domain.distribution.distribution_cell_value_types import DistributionCellValueType
@@ -100,10 +101,14 @@ class DistributionSheet(Sheet):
         if cell_value_type is DistributionCellValueType.TEXT:
             self.distribution_data.blocks.append(
                 DataBlock(
-                    text=[self.sheet_reader.read_cell(
-                        row=row_index,
-                        col=col_index,
-                    ).value],
+                    text=[
+                        TextLine(
+                            text=self.sheet_reader.read_cell(
+                                row=row_index,
+                                col=col_index,
+                            ).value
+                        ),
+                    ],
                 )
             )
         elif cell_value_type is DistributionCellValueType.TITLE:
